@@ -89,18 +89,21 @@ sub runCommands {
 
 # generate tftp config variables
 sub generate_tftp_cmd {
+
   # load modules
   use Carp;
   use POSIX qw/strftime/;
 
-  my ($self, $ip, $hostname) = @_;
+  my ( $self, $ip, $hostname ) = @_;
   $hostname = $ip unless defined $hostname;
   confess "must provide ip and hostname" if not defined $ip or $ip eq "";
 
   my $tftp_server = $self->tftp_server;
+
   # init variables
-  my $dir  = strftime( "%Y-%m",   localtime );
+  my $dir  = strftime( "%Y-%m",  localtime );
   my $time = strftime( "%Y%m%d", localtime );
+
   # generate tftp path
   my $tftp_destination = $tftp_server . "$dir/$time/$ip-$hostname.config";
 
@@ -110,9 +113,10 @@ sub generate_tftp_cmd {
 
 # 支持 tftp 保存运行配置
 sub copy_config_by_tftp {
- my ($self, $ip, $hostname) = @_;
+  my ( $self, $ip, $hostname ) = @_;
+
   # 生成命令
-  my $cmd = $self->generate_tftp_cmd;
+  my $cmd = $self->generate_tftp_cmd( $ip, $hostname );
 
   # 执行脚本
   return $self->execCommands($cmd);
